window.Gleam.initSearch([{"doc":"glexec","title":"glexec","content":"# glexec\n\n[![Package Version](https://img.shields.io/hexpm/v/glexec)](https://hex.pm/packages/glexec)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glexec/)\n\nA wrapper around the functions found in\n[erlexec](https://hexdocs.pm/erlexec/exec.html).\n\nIt probably goes without saying, but this functionality is only available when\nrunnning on BEAM.\n\n## Quick start\n\n```gleam\nimport glexec as exec\n\npub fn main() {\n  let assert Ok(bash) = exec.find_executable(&quot;bash&quot;)\n\n  let assert Ok(exec.Pids(_pid, ospid)) =\n    exec.new()\n    |&gt; exec.with_stdin(exec.StdinPipe)\n    |&gt; exec.with_stdout(exec.StdoutCapture)\n    |&gt; exec.with_stderr(exec.StderrStdout)\n    |&gt; exec.with_monitor(True)\n    |&gt; exec.with_pty(True)\n    |&gt; exec.run_async(exec.Execve([bash, &quot;-c&quot;, &quot;echo started &amp;&amp; cat&quot;]))\n\n  let assert Ok(exec.ObtainStdout(_, &quot;started\\r\\n&quot;)) = exec.obtain(500)\n  let assert Ok(Nil) = exec.send(ospid, &quot;test\\n&quot;)\n  let assert Ok(exec.ObtainStdout(_, &quot;test\\r\\n&quot;)) = exec.obtain(500)\n  let assert Ok(Nil) = exec.kill_ospid(ospid, 9)\n}\n```\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add glexec\n```\n\n## Development\n\n```sh\ngleam test  # Run the tests\ngleam run   # Run a small example\ngleam shell # Run an Erlang shell\n```\n\n## TODO\n\nThe test suite is still fairly incomplete, but without code coverage it is a\nbit hard to ensure all cases are covered and the main functionality is tested\nin `erlexec` itself.\n\nHappy for any PRs though.\n","url":"index.html"},{"doc":"glexec","title":"Command","content":"pub type Command {\n  Shell(String)\n  Execve(List(String))\n}\n Command to be executed.\nShell(String)\n The specified command will be executed through the shell. The current shell\n is obtained from environment variable `SHELL`.\n\n This can be useful primarily for the enhanced control flow it offers over\n most system shells and still want convenient access to other shell features\n such as shell pipes, filename wildcards, environment variable expansion,\n and expansion of `~` to a user&#39;s home directory. All command arguments must\n be properly escaped including whitespace and shell metacharacters.\n\n Warning: Executing shell commands that incorporate unsanitized input from\n an untrusted source makes a program vulnerable to shell injection, a\n serious security flaw which can result in arbitrary command execution. For\n this reason, the use of shell is strongly discouraged in cases where the\n command string is constructed from external input. \n\nExecve(List(String))\n Command is passed to `execve(3)` library call directly without involving\n the shell process, so the list of strings represents the program to be\n executed with arguments. In this case all shell-based features are disabled\n and there&#39;s no shell injection vulnerability.\n\nSynonyms:\nglexec.Command\nglexec Command","url":"glexec.html#Command"},{"doc":"glexec","title":"EnvOption","content":"pub type EnvOption {\n  EnvString(String)\n  EnvClear\n  EnvKV(String, String)\n  EnvUnset(String)\n}\n\nEnvString(String)\n\n\nEnvClear\n\n\nEnvKV(String, String)\n\n\nEnvUnset(String)\n\n\nSynonyms:\nglexec.EnvOption\nglexec EnvOption","url":"glexec.html#EnvOption"},{"doc":"glexec","title":"EnvOptions","content":"pub type EnvOptions =\n  List(EnvOption)\n\n\nSynonyms:\nglexec.EnvOptions\nglexec EnvOptions","url":"glexec.html#EnvOptions"},{"doc":"glexec","title":"ExitStatusOrSignal","content":"pub type ExitStatusOrSignal {\n  ExitStatus(Int)\n  Signal(status: Signal, core_dump: Bool)\n}\n\nExitStatus(Int)\n\n\nSignal(status: Signal, core_dump: Bool)\n\n\nSynonyms:\nglexec.ExitStatusOrSignal\nglexec ExitStatusOrSignal","url":"glexec.html#ExitStatusOrSignal"},{"doc":"glexec","title":"FindExecutableError","content":"pub type FindExecutableError {\n  ExecutableNotFound\n}\n\nExecutableNotFound\n\n\nSynonyms:\nglexec.FindExecutableError\nglexec FindExecutableError","url":"glexec.html#FindExecutableError"},{"doc":"glexec","title":"ObtainError","content":"pub type ObtainError {\n  ObtainTimeout\n  ObtainDownStatus(Pid, OsPid, Int)\n  ObtainDownNormal(Pid, OsPid)\n  ObtainDownNoproc(Pid, OsPid)\n}\n\nObtainTimeout\n\n\nObtainDownStatus(Pid, OsPid, Int)\n\n\nObtainDownNormal(Pid, OsPid)\n\n\nObtainDownNoproc(Pid, OsPid)\n\n\nSynonyms:\nglexec.ObtainError\nglexec ObtainError","url":"glexec.html#ObtainError"},{"doc":"glexec","title":"ObtainOk","content":"pub type ObtainOk {\n  ObtainStdout(Int, String)\n  ObtainStderr(Int, String)\n}\n\nObtainStdout(Int, String)\n\n\nObtainStderr(Int, String)\n\n\nSynonyms:\nglexec.ObtainOk\nglexec ObtainOk","url":"glexec.html#ObtainOk"},{"doc":"glexec","title":"Options","content":"pub opaque type Options\n Keeps track of all the options that will be passed to\n [run_async](#run_async) or [run_sync](#run_sync)\n\nSynonyms:\nglexec.Options\nglexec Options","url":"glexec.html#Options"},{"doc":"glexec","title":"OsGid","content":"pub type OsGid =\n  Int\n Representation of OS group ID\n\nSynonyms:\nglexec.OsGid\nglexec OsGid","url":"glexec.html#OsGid"},{"doc":"glexec","title":"OsPid","content":"pub type OsPid =\n  Int\n Representation of OS process ID\n\nSynonyms:\nglexec.OsPid\nglexec OsPid","url":"glexec.html#OsPid"},{"doc":"glexec","title":"Output","content":"pub type Output {\n  Output(List(StdoutOrStderr))\n}\n\nOutput(List(StdoutOrStderr))\n\n\nSynonyms:\nglexec.Output\nglexec Output","url":"glexec.html#Output"},{"doc":"glexec","title":"Pids","content":"pub type Pids {\n  Pids(Pid, OsPid)\n}\n\nPids(Pid, OsPid)\n `Pid` is the Erlang process identifier.\n `OsPid` is the OS process identifier of the new process.\n\nSynonyms:\nglexec.Pids\nglexec Pids","url":"glexec.html#Pids"},{"doc":"glexec","title":"PtyOption","content":"pub type PtyOption {\n  Vintr(Int)\n  Vquit(Int)\n  Verase(Int)\n  Vkill(Int)\n  Veof(Int)\n  Veol(Int)\n  Veol2(Int)\n  Vstart(Int)\n  Vstop(Int)\n  Vsusp(Int)\n  Vdsusp(Int)\n  Vreprint(Int)\n  Vwerase(Int)\n  Vlnext(Int)\n  Vflush(Int)\n  Vswtch(Int)\n  Vstatus(Int)\n  Vdiscard(Int)\n  Ignpar(Bool)\n  Parmrk(Bool)\n  Inpck(Bool)\n  Istrip(Bool)\n  Inlcr(Bool)\n  Igncr(Bool)\n  Icrnl(Bool)\n  Xcase(Bool)\n  Iuclc(Bool)\n  Ixon(Bool)\n  Ixany(Bool)\n  Ixoff(Bool)\n  Imaxbel(Bool)\n  Iutf8(Bool)\n  Isig(Bool)\n  Icanon(Bool)\n  Echo(Bool)\n  Echoe(Bool)\n  Echok(Bool)\n  Echonl(Bool)\n  Noflsh(Bool)\n  Tostop(Bool)\n  Iexten(Bool)\n  Echoctl(Bool)\n  Echoke(Bool)\n  Pendin(Bool)\n  Opost(Bool)\n  Olcuc(Bool)\n  Onlcr(Bool)\n  Ocrnl(Bool)\n  Onocr(Bool)\n  Onlret(Bool)\n  Cs7(Bool)\n  Cs8(Bool)\n  Parenb(Bool)\n  Parodd(Bool)\n  TtyOpIspeed(Int)\n  TtyOpOspeed(Int)\n}\n For documentation please check:\n - [termios(3)](https://man7.org/linux/man-pages/man3/termios.3.html)\n - [RFC4254](https://datatracker.ietf.org/doc/html/rfc4254#section-8)\nVintr(Int)\n\n\nVquit(Int)\n\n\nVerase(Int)\n\n\nVkill(Int)\n\n\nVeof(Int)\n\n\nVeol(Int)\n\n\nVeol2(Int)\n\n\nVstart(Int)\n\n\nVstop(Int)\n\n\nVsusp(Int)\n\n\nVdsusp(Int)\n\n\nVreprint(Int)\n\n\nVwerase(Int)\n\n\nVlnext(Int)\n\n\nVflush(Int)\n\n\nVswtch(Int)\n\n\nVstatus(Int)\n\n\nVdiscard(Int)\n\n\nIgnpar(Bool)\n\n\nParmrk(Bool)\n\n\nInpck(Bool)\n\n\nIstrip(Bool)\n\n\nInlcr(Bool)\n\n\nIgncr(Bool)\n\n\nIcrnl(Bool)\n\n\nXcase(Bool)\n\n\nIuclc(Bool)\n\n\nIxon(Bool)\n\n\nIxany(Bool)\n\n\nIxoff(Bool)\n\n\nImaxbel(Bool)\n\n\nIutf8(Bool)\n\n\nIsig(Bool)\n\n\nIcanon(Bool)\n\n\nEcho(Bool)\n\n\nEchoe(Bool)\n\n\nEchok(Bool)\n\n\nEchonl(Bool)\n\n\nNoflsh(Bool)\n\n\nTostop(Bool)\n\n\nIexten(Bool)\n\n\nEchoctl(Bool)\n\n\nEchoke(Bool)\n\n\nPendin(Bool)\n\n\nOpost(Bool)\n\n\nOlcuc(Bool)\n\n\nOnlcr(Bool)\n\n\nOcrnl(Bool)\n\n\nOnocr(Bool)\n\n\nOnlret(Bool)\n\n\nCs7(Bool)\n\n\nCs8(Bool)\n\n\nParenb(Bool)\n\n\nParodd(Bool)\n\n\nTtyOpIspeed(Int)\n\n\nTtyOpOspeed(Int)\n\n\nSynonyms:\nglexec.PtyOption\nglexec PtyOption","url":"glexec.html#PtyOption"},{"doc":"glexec","title":"PtyOptions","content":"pub type PtyOptions {\n  PtyEnable\n  PtyOpts(List(PtyOption))\n}\n\nPtyEnable\n\n\nPtyOpts(List(PtyOption))\n\n\nSynonyms:\nglexec.PtyOptions\nglexec PtyOptions","url":"glexec.html#PtyOptions"},{"doc":"glexec","title":"RunError","content":"pub type RunError {\n  RunError(exit_status: Int, output: List(StdoutOrStderr))\n}\n\nRunError(exit_status: Int, output: List(StdoutOrStderr))\n\n\nSynonyms:\nglexec.RunError\nglexec RunError","url":"glexec.html#RunError"},{"doc":"glexec","title":"Signal","content":"pub type Signal {\n  SIGHUP\n  SIGINT\n  SIGQUIT\n  SIGILL\n  SIGTRAP\n  SIGABRT\n  SIGBUS\n  SIGFPE\n  SIGKILL\n  SIGUSR1\n  SIGSEGV\n  SIGUSR2\n  SIGPIPE\n  SIGALRM\n  SIGTERM\n  SIGSTKFLT\n  SIGCHLD\n  SIGCONT\n  SIGSTOP\n  SIGTSTP\n  SIGTTIN\n  SIGTTOU\n  SIGURG\n  SIGXCPU\n  SIGXFSZ\n  SIGVTALRM\n  SIGPROF\n  SIGWINCH\n  SIGIO\n  SIGPWR\n  SIGSYS\n  Other(Int)\n}\n\nSIGHUP\n\n\nSIGINT\n\n\nSIGQUIT\n\n\nSIGILL\n\n\nSIGTRAP\n\n\nSIGABRT\n\n\nSIGBUS\n\n\nSIGFPE\n\n\nSIGKILL\n\n\nSIGUSR1\n\n\nSIGSEGV\n\n\nSIGUSR2\n\n\nSIGPIPE\n\n\nSIGALRM\n\n\nSIGTERM\n\n\nSIGSTKFLT\n\n\nSIGCHLD\n\n\nSIGCONT\n\n\nSIGSTOP\n\n\nSIGTSTP\n\n\nSIGTTIN\n\n\nSIGTTOU\n\n\nSIGURG\n\n\nSIGXCPU\n\n\nSIGXFSZ\n\n\nSIGVTALRM\n\n\nSIGPROF\n\n\nSIGWINCH\n\n\nSIGIO\n\n\nSIGPWR\n\n\nSIGSYS\n\n\nOther(Int)\n\n\nSynonyms:\nglexec.Signal\nglexec Signal","url":"glexec.html#Signal"},{"doc":"glexec","title":"StartError","content":"pub type StartError {\n  AlreadyStarted(Pid)\n}\n\nAlreadyStarted(Pid)\n\n\nSynonyms:\nglexec.StartError\nglexec StartError","url":"glexec.html#StartError"},{"doc":"glexec","title":"StartOption","content":"pub type StartOption {\n  StartDebug(level: Int)\n  StartRoot(enable: Bool)\n  StartVerbose\n  StartArgs(List(String))\n  StartAlarm(seconds: Int)\n  StartUser(String)\n  StartLimitUsers(List(String))\n  StartPortexe(String)\n  StartEnv(EnvOptions)\n}\n\nStartDebug(level: Int)\n\n\nStartRoot(enable: Bool)\n\n\nStartVerbose\n\n\nStartArgs(List(String))\n\n\nStartAlarm(seconds: Int)\n\n\nStartUser(String)\n\n\nStartLimitUsers(List(String))\n\n\nStartPortexe(String)\n\n\nStartEnv(EnvOptions)\n\n\nSynonyms:\nglexec.StartOption\nglexec StartOption","url":"glexec.html#StartOption"},{"doc":"glexec","title":"StderrOptions","content":"pub type StderrOptions {\n  StderrCapture\n  StderrClose\n  StderrFun(fn(Atom, Int, String) -&gt; Nil)\n  StderrNull\n  StderrPid(Pid)\n  StderrPrint\n  StderrStdout\n  StderrString(String)\n}\n\nStderrCapture\n\n\nStderrClose\n\n\nStderrFun(fn(Atom, Int, String) -&gt; Nil)\n\n\nStderrNull\n\n\nStderrPid(Pid)\n\n\nStderrPrint\n\n\nStderrStdout\n\n\nStderrString(String)\n\n\nSynonyms:\nglexec.StderrOptions\nglexec StderrOptions","url":"glexec.html#StderrOptions"},{"doc":"glexec","title":"StdinOptions","content":"pub type StdinOptions {\n  StdinClose\n  StdinNull\n  StdinPipe\n  StdinFrom(String)\n}\n\nStdinClose\n\n\nStdinNull\n\n\nStdinPipe\n\n\nStdinFrom(String)\n\n\nSynonyms:\nglexec.StdinOptions\nglexec StdinOptions","url":"glexec.html#StdinOptions"},{"doc":"glexec","title":"StdoutOptions","content":"pub type StdoutOptions {\n  StdoutCapture\n  StdoutClose\n  StdoutFun(fn(Atom, Int, String) -&gt; Nil)\n  StdoutNull\n  StdoutPid(Pid)\n  StdoutPrint\n  StdoutStderr\n  StdoutString(String)\n}\n\nStdoutCapture\n\n\nStdoutClose\n\n\nStdoutFun(fn(Atom, Int, String) -&gt; Nil)\n\n\nStdoutNull\n\n\nStdoutPid(Pid)\n\n\nStdoutPrint\n\n\nStdoutStderr\n\n\nStdoutString(String)\n\n\nSynonyms:\nglexec.StdoutOptions\nglexec StdoutOptions","url":"glexec.html#StdoutOptions"},{"doc":"glexec","title":"StdoutOrStderr","content":"pub type StdoutOrStderr {\n  Stdout(List(String))\n  Stderr(List(String))\n}\n\nStdout(List(String))\n\n\nStderr(List(String))\n\n\nSynonyms:\nglexec.StdoutOrStderr\nglexec StdoutOrStderr","url":"glexec.html#StdoutOrStderr"},{"doc":"glexec","title":"StopError","content":"pub type StopError {\n  NoProcess\n}\n\nNoProcess\n\n\nSynonyms:\nglexec.StopError\nglexec StopError","url":"glexec.html#StopError"},{"doc":"glexec","title":"debug","content":"pub fn debug(level: Int) -&gt; Result(Int, Atom)\n Set the global debug level\nSynonyms:\nglexec.debug\nglexec debug","url":"glexec.html#debug"},{"doc":"glexec","title":"find_executable","content":"pub fn find_executable(\n  name: String,\n) -&gt; Result(String, FindExecutableError)\n Tries to find the given executable name and returns the full path to it.\nSynonyms:\nglexec.find_executable\nglexec find_executable","url":"glexec.html#find_executable"},{"doc":"glexec","title":"get_cd","content":"pub fn get_cd(options: Options) -&gt; Option(String)\n\nSynonyms:\nglexec.get_cd\nglexec get_cd","url":"glexec.html#get_cd"},{"doc":"glexec","title":"get_env","content":"pub fn get_env(options: Options) -&gt; List(EnvOption)\n\nSynonyms:\nglexec.get_env\nglexec get_env","url":"glexec.html#get_env"},{"doc":"glexec","title":"get_executable","content":"pub fn get_executable(options: Options) -&gt; Option(String)\n\nSynonyms:\nglexec.get_executable\nglexec get_executable","url":"glexec.html#get_executable"},{"doc":"glexec","title":"get_kill","content":"pub fn get_kill(options: Options) -&gt; Option(String)\n\nSynonyms:\nglexec.get_kill\nglexec get_kill","url":"glexec.html#get_kill"},{"doc":"glexec","title":"get_link","content":"pub fn get_link(options: Options) -&gt; Bool\n\nSynonyms:\nglexec.get_link\nglexec get_link","url":"glexec.html#get_link"},{"doc":"glexec","title":"get_monitor","content":"pub fn get_monitor(options: Options) -&gt; Bool\n\nSynonyms:\nglexec.get_monitor\nglexec get_monitor","url":"glexec.html#get_monitor"},{"doc":"glexec","title":"get_pty","content":"pub fn get_pty(options: Options) -&gt; Bool\n\nSynonyms:\nglexec.get_pty\nglexec get_pty","url":"glexec.html#get_pty"},{"doc":"glexec","title":"get_stderr","content":"pub fn get_stderr(options: Options) -&gt; Option(StderrOptions)\n\nSynonyms:\nglexec.get_stderr\nglexec get_stderr","url":"glexec.html#get_stderr"},{"doc":"glexec","title":"get_stdin","content":"pub fn get_stdin(options: Options) -&gt; Option(StdinOptions)\n\nSynonyms:\nglexec.get_stdin\nglexec get_stdin","url":"glexec.html#get_stdin"},{"doc":"glexec","title":"get_stdout","content":"pub fn get_stdout(options: Options) -&gt; Option(StdoutOptions)\n\nSynonyms:\nglexec.get_stdout\nglexec get_stdout","url":"glexec.html#get_stdout"},{"doc":"glexec","title":"int_to_signal","content":"pub fn int_to_signal(signal: Int) -&gt; Signal\n\nSynonyms:\nglexec.int_to_signal\nglexec int_to_signal","url":"glexec.html#int_to_signal"},{"doc":"glexec","title":"kill_ospid","content":"pub fn kill_ospid(\n  ospid: Int,\n  signal: Int,\n) -&gt; Result(Nil, Dynamic)\n Send a signal to an OsPid.\nSynonyms:\nglexec.kill_ospid\nglexec kill_ospid","url":"glexec.html#kill_ospid"},{"doc":"glexec","title":"kill_pid","content":"pub fn kill_pid(pid: Pid, signal: Int) -&gt; Result(Nil, Dynamic)\n Send a signal to a child Pid.\nSynonyms:\nglexec.kill_pid\nglexec kill_pid","url":"glexec.html#kill_pid"},{"doc":"glexec","title":"manage_pid","content":"pub fn manage_pid(pid: Pid, options: Options) -&gt; Dynamic\n\nSynonyms:\nglexec.manage_pid\nglexec manage_pid","url":"glexec.html#manage_pid"},{"doc":"glexec","title":"new","content":"pub fn new() -&gt; Options\n Initial constructor for Options. Changing these settings is done with the\n `with_*` functions.\nSynonyms:\nglexec.new\nglexec new","url":"glexec.html#new"},{"doc":"glexec","title":"obtain","content":"pub fn obtain(\n  timeout_in_milliseconds: Int,\n) -&gt; Result(ObtainOk, ObtainError)\n\nSynonyms:\nglexec.obtain\nglexec obtain","url":"glexec.html#obtain"},{"doc":"glexec","title":"options_to_list","content":"pub fn options_to_list(options: Options) -&gt; List(Dynamic)\n\nSynonyms:\nglexec.options_to_list\nglexec options_to_list","url":"glexec.html#options_to_list"},{"doc":"glexec","title":"run_async","content":"pub fn run_async(\n  options: Options,\n  command: Command,\n) -&gt; Result(Pids, String)\n Run command with the given options, don&#39;t wait for it to finish.\nSynonyms:\nglexec.run_async\nglexec run_async","url":"glexec.html#run_async"},{"doc":"glexec","title":"run_sync","content":"pub fn run_sync(\n  options: Options,\n  command: Command,\n) -&gt; Result(Output, RunError)\n Run command with the given options, block the caller until it exits.\nSynonyms:\nglexec.run_sync\nglexec run_sync","url":"glexec.html#run_sync"},{"doc":"glexec","title":"send","content":"pub fn send(ospid: Int, data: String) -&gt; Result(Nil, Dynamic)\n\nSynonyms:\nglexec.send\nglexec send","url":"glexec.html#send"},{"doc":"glexec","title":"send_eof","content":"pub fn send_eof(ospid: Int) -&gt; Result(Nil, Dynamic)\n This will close `stdin`.\nSynonyms:\nglexec.send_eof\nglexec send_eof","url":"glexec.html#send_eof"},{"doc":"glexec","title":"signal_to_int","content":"pub fn signal_to_int(signal: Signal) -&gt; Int\n\nSynonyms:\nglexec.signal_to_int\nglexec signal_to_int","url":"glexec.html#signal_to_int"},{"doc":"glexec","title":"start","content":"pub fn start(\n  options: List(StartOption),\n) -&gt; Result(Pid, StartError)\n Start the `exec` application\nSynonyms:\nglexec.start\nglexec start","url":"glexec.html#start"},{"doc":"glexec","title":"status","content":"pub fn status(status: Int) -&gt; ExitStatusOrSignal\n  Decode the program&#39;s exit_status.\n\n  If the program exited by signal the function returns [Signal](#Signal),\n  otherwise it will return an [ExitStatus](#ExitStatus)\nSynonyms:\nglexec.status\nglexec status","url":"glexec.html#status"},{"doc":"glexec","title":"stop","content":"pub fn stop(pid: Int) -&gt; Result(Nil, String)\n Terminate a managed `Pid`, `OsPid`, or Port process.\n The OS process is terminated gracefully. If it was given a `{kill, Cmd}`\n option at startup, that command is executed and a timer is started. If the\n program doesn&#39;t exit, then the default termination is performed. Default\n termination implies sending a `SIGTERM` command followed by a `SIGKILL` in 5\n seconds, if the program doesn&#39;t get killed.\nSynonyms:\nglexec.stop\nglexec stop","url":"glexec.html#stop"},{"doc":"glexec","title":"to_ospid","content":"pub fn to_ospid(ospid: Pid) -&gt; Result(Int, Dynamic)\n\nSynonyms:\nglexec.to_ospid\nglexec to_ospid","url":"glexec.html#to_ospid"},{"doc":"glexec","title":"which_children","content":"pub fn which_children() -&gt; List(Int)\n Get a list of children OsPids managed by the port program.\nSynonyms:\nglexec.which_children\nglexec which_children","url":"glexec.html#which_children"},{"doc":"glexec","title":"winsz","content":"pub fn winsz(\n  pid: Int,\n  rows: Int,\n  columns: Int,\n) -&gt; Result(Nil, Nil)\n\nSynonyms:\nglexec.winsz\nglexec winsz","url":"glexec.html#winsz"},{"doc":"glexec","title":"with_cd","content":"pub fn with_cd(old: Options, given: String) -&gt; Options\n Set a working directory\nSynonyms:\nglexec.with_cd\nglexec with_cd","url":"glexec.html#with_cd"},{"doc":"glexec","title":"with_debug","content":"pub fn with_debug(old: Options, level: Int) -&gt; Options\n Configure debug printing for this command.\n\n The `level` should be `0 &lt;= level =&lt; 10`\nSynonyms:\nglexec.with_debug\nglexec with_debug","url":"glexec.html#with_debug"},{"doc":"glexec","title":"with_env","content":"pub fn with_env(old: Options, given: List(EnvOption)) -&gt; Options\n Modify the program environment. See [EnvOption](#EnvOption)\nSynonyms:\nglexec.with_env\nglexec with_env","url":"glexec.html#with_env"},{"doc":"glexec","title":"with_executable","content":"pub fn with_executable(old: Options, given: String) -&gt; Options\n Specifies a replacement program to execute.\n\n It is very seldom needed. When the port program executes a child process\n using `execve(3)` call, the call takes the following arguments:\n `(executable, args, env)`.\n When the `command` argument is specified as the list of strings, the\n executable replaces the first parameter in the call, and the original\n `args` provided in the `command` parameter are passed as as the second\n parameter.\n Most programs treat the program specified by `args` as the command name,\n which can then be different from the program actually executed.\n \n ### Unix specific:\n\n The `args` name becomes the display name for the executable in utilities\n such as `ps`.\n\n If the `command` argument is a Shell, the `Executable` specifies a\n replacement shell for the default `/bin/sh`.\nSynonyms:\nglexec.with_executable\nglexec with_executable","url":"glexec.html#with_executable"},{"doc":"glexec","title":"with_group","content":"pub fn with_group(old: Options, given: Int) -&gt; Options\n Sets the effective group ID of the spawned process. The value `0` means to\n create a new group ID equal to the OS pid of the process.\nSynonyms:\nglexec.with_group\nglexec with_group","url":"glexec.html#with_group"},{"doc":"glexec","title":"with_kill","content":"pub fn with_kill(old: Options, command: String) -&gt; Options\n This command will be used for killing the process.\n\n If the process is still alive after 5 seconds, it receives a `SIGKILL`.\n\n The kill command will have a `CHILD_PID` environment variable set to the\n pid of the process it is expected to kill.\n\n If the `kill` option is not specified, by default first the command is sent\n a `SIGTERM` signal, followed by `SIGKILL` after a default timeout.\nSynonyms:\nglexec.with_kill\nglexec with_kill","url":"glexec.html#with_kill"},{"doc":"glexec","title":"with_kill_group","content":"pub fn with_kill_group(old: Options, given: Bool) -&gt; Options\n At process exit kill the whole process group associated with this pid.\n The process group is obtained by the call to `getpgid(3)`.\nSynonyms:\nglexec.with_kill_group\nglexec with_kill_group","url":"glexec.html#with_kill_group"},{"doc":"glexec","title":"with_kill_timeout","content":"pub fn with_kill_timeout(old: Options, given: Int) -&gt; Options\n Number of seconds to wait after issuing a SIGTERM or\n executing the custom `kill` command (if specified) before\n killing the process with the `SIGKILL` signal\nSynonyms:\nglexec.with_kill_timeout\nglexec with_kill_timeout","url":"glexec.html#with_kill_timeout"},{"doc":"glexec","title":"with_link","content":"pub fn with_link(old: Options, given: Bool) -&gt; Options\n Link to the OsPid. If OsPid exits, the calling process will be killed or if\n it&#39;s trapping exits, it&#39;ll get {&#39;EXIT&#39;, OsPid, Status} message.  If the\n calling process dies the OsPid will be killed.\n The `Status` can be decoded with [status](#status) to determine the\n process&#39;s exit code and if it was killed by signal.\nSynonyms:\nglexec.with_link\nglexec with_link","url":"glexec.html#with_link"},{"doc":"glexec","title":"with_monitor","content":"pub fn with_monitor(old: Options, given: Bool) -&gt; Options\n Set up a monitor for the spawned process.\n\n The monitor is not a standard `erlang:monitor/2` function call, but\n it&#39;s emulated by ensuring that the monitoring process receives\n notifications in the form:\n `{&#39;DOWN&#39;, OsPid::integer(), process, Pid::pid(), Reason}`.\n\n If the `Reason` is `normal`, then process exited with status `0`,\n otherwise there was an error. If the Reason is `{status, Status}` the\n returned `Status` can be decoded with the [status](#status) function to\n determine the exit code of the process and if it was killed by signal.\nSynonyms:\nglexec.with_monitor\nglexec with_monitor","url":"glexec.html#with_monitor"},{"doc":"glexec","title":"with_nice","content":"pub fn with_nice(old: Options, priority: Int) -&gt; Options\n Set process priority between `-20` and `20`. Note that negative values\n can be specified only when `exec-port` is started with a root suid bit\n set.\nSynonyms:\nglexec.with_nice\nglexec with_nice","url":"glexec.html#with_nice"},{"doc":"glexec","title":"with_pty","content":"pub fn with_pty(old: Options, enable_pty: Bool) -&gt; Options\n Use pseudo terminal for the process&#39;s stdin, stdout and stderr\nSynonyms:\nglexec.with_pty\nglexec with_pty","url":"glexec.html#with_pty"},{"doc":"glexec","title":"with_pty_echo","content":"pub fn with_pty_echo(old: Options, given: Bool) -&gt; Options\n Allow the pty to run in echo mode, disabled by default.\nSynonyms:\nglexec.with_pty_echo\nglexec with_pty_echo","url":"glexec.html#with_pty_echo"},{"doc":"glexec","title":"with_stderr","content":"pub fn with_stderr(old: Options, given: StderrOptions) -&gt; Options\n Configure `stderr` communication with the OS process.\n See [StderrOptions](#StderrOptions)\nSynonyms:\nglexec.with_stderr\nglexec with_stderr","url":"glexec.html#with_stderr"},{"doc":"glexec","title":"with_stdin","content":"pub fn with_stdin(old: Options, given: StdinOptions) -&gt; Options\n Configure `stdin` communication with the OS process.\n See [StdinOptions](#StdinOptions)\nSynonyms:\nglexec.with_stdin\nglexec with_stdin","url":"glexec.html#with_stdin"},{"doc":"glexec","title":"with_stdout","content":"pub fn with_stdout(old: Options, given: StdoutOptions) -&gt; Options\n Configure `stdout` communication with the OS process.\n See [StdoutOptions](#StdoutOptions)\nSynonyms:\nglexec.with_stdout\nglexec with_stdout","url":"glexec.html#with_stdout"},{"doc":"glexec","title":"with_success_exit_code","content":"pub fn with_success_exit_code(\n  old: Options,\n  given: Int,\n) -&gt; Options\n Return value on success.\nSynonyms:\nglexec.with_success_exit_code\nglexec with_success_exit_code","url":"glexec.html#with_success_exit_code"},{"doc":"glexec","title":"with_user","content":"pub fn with_user(old: Options, given: String) -&gt; Options\n When `exec-port` was compiled with capability (Linux) support enabled\n and has a suid bit set, it&#39;s capable of running commands with a\n different effective user. The value &quot;root&quot; is prohibited.\nSynonyms:\nglexec.with_user\nglexec with_user","url":"glexec.html#with_user"},{"doc":"glexec","title":"with_verbose","content":"pub fn with_verbose(old: Options, enabled: Bool) -&gt; Options\n\nSynonyms:\nglexec.with_verbose\nglexec with_verbose","url":"glexec.html#with_verbose"},{"doc":"glexec","title":"with_winsz","content":"pub fn with_winsz(\n  old: Options,\n  rows: Int,\n  columns: Int,\n) -&gt; Options\n\nSynonyms:\nglexec.with_winsz\nglexec with_winsz","url":"glexec.html#with_winsz"},{"doc":"glexec","title":"glexec","content":" OS shell command runner. It communicates with a separate C++ port process\n exec-port spawned by this module, which is responsible for starting,\n killing, listing, terminating, and notifying of state changes.\n\n For more detailed documentation, please refer to\n https://hexdocs.pm/erlexec/exec.html","url":"glexec.html"},{"doc":"example","title":"main","content":"pub fn main() -&gt; Result(ObtainOk, ObtainError)\n\nSynonyms:\nexample.main\nexample main","url":"example.html#main"},{"doc":"example","title":"example","content":"","url":"example.html"}]);